@@ -145,6 +145,9 @@ nominalTrainWorkflow <- function(dat, info, method, ppOpts, ctrl, lev, testing =
           tmp <-  data.frame(pred = predicted,
                              obs = dat$.outcome[holdoutIndex],
                              stringsAsFactors = FALSE)
+          ## Sometimes the code above does not coerce the first
+          ## columnn to be named "pred" so force it
+          names(tmp)[1] <- "pred"
           if(ctrl$classProbs) tmp <- cbind(tmp, probValues)
 
 
@@ -164,7 +167,6 @@ nominalTrainWorkflow <- function(dat, info, method, ppOpts, ctrl, lev, testing =
       thisResample
     }
 
-
    if(ctrl$method %in% c("boot632"))
       {
         perfNames <- names(ctrl$summaryFunction(data.frame(obs = dat$.outcome, pred = sample(dat$.outcome)),
